@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2017 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -46,6 +46,40 @@ class ImageGrabberDevice;
 class Frontend
 {
 public:
+
+    /**
+     * @brief V4L2 grabber enable default for new installations
+     */
+    const static bool V4L2GRABBERDEFAULT = true;
+
+    /**
+     * @brief V4L2 controler enable default for new installations
+     */
+    const static bool V4L2CONTROLERDEFAULT = true;
+
+    /**
+     * @brief MediaFoundation grabber enable default for new installations
+     */
+    const static bool MEDIAFOUNDATIONGRABBERDEFAULT = true;
+
+    /**
+     * @brief MesiaFoundation controler enable default for new installations
+     */
+    const static bool MEDIAFOUNDATIONCONTROLERDEFAULT = true;
+
+    /**
+     * @brief GPhoto2 grabber enable default for new installations
+     */
+    const static bool GPHOTO2GRABBERDEFAULT = false;
+
+    /**
+     * @brief GPhoto2 controler enable default for new installations
+     */
+    const static bool GPHOTO2CONTROLERDEFAULT = false;
+
+    /**
+     * @brief Destructor
+     */
     virtual ~Frontend() {}
 
     /**
@@ -128,6 +162,12 @@ public:
      */
     virtual const QString getPicturesDirName() = 0;
 
+    /**
+     * Abstract function for getting the sounds directory
+     * @return the sounds directory name string
+     */
+    virtual const QString getSoundsDirName() = 0;
+
     /**
      * Abstract function for getting all possible GUI languages
      * @return A vector with all languages
@@ -218,6 +258,18 @@ public:
      */
     virtual void setGridColorRGB(int r, int g, int b, int a) = 0;
 
+    /**
+     * Get the status of the signal feature.
+     * @return The new state of the signal feature.
+     */
+    virtual bool getSignal() = 0;
+
+    /**
+     * Set the status of the signal feature.
+     * @param newState The new state of the signal feature.
+     */
+    virtual void setSignal(bool newState) = 0;
+
     /**
      * Abstract function for displaying progress on timeconsuming operations.
      * @param infoText the text to display to the user
@@ -454,6 +506,12 @@ public:
      */
     virtual void setToolBarState(int newState) = 0;
 
+    /**
+     * Open the online help in the default internet browser
+     * @param anchor The anchor in the manual to go to after the manual is opend
+     */
+    virtual void openOnlineHelp(const QString &anchor) = 0;
+
     /**************************************************************************
      * Project preferences
      **************************************************************************/
@@ -470,6 +528,56 @@ public:
      */
     virtual void setRecordingMode(int mode) = 0;
 
+    /**
+     * Get the unit mode.
+     * @return The unit mode.
+     */
+    virtual int getUnitMode() = 0;
+
+    /**
+     * Set the unit mode.
+     * @param mode The new unit mode.
+     */
+    virtual void setUnitMode(int mode) = 0;
+
+    /**
+     * Get the unit count.
+     * @return The unit count.
+     */
+    virtual int getUnitCount() = 0;
+
+    /**
+     * Set the unit count.
+     * @param count The new unit count.
+     */
+    virtual void setUnitCount(int count) = 0;
+
+    /**
+     * Get the beep checkbox state.
+     * @brief getBeepState
+     * @return The actual beep checkbox state
+     */
+    virtual bool getBeepState() = 0;
+
+    /**
+     * Set the beep checkbox state.
+     * @brief setBeepState
+     * @param state The new beep checkbox state.
+     */
+    virtual void setBeepState(bool state) = 0;
+
+    /**
+     * Get the beep unit count.
+     * @return The beep unit count.
+     */
+    virtual int getBeepCount() = 0;
+
+    /**
+     * Set the beep unit count.
+     * @param count The new beep unit count.
+     */
+    virtual void setBeepCount(int count) = 0;
+
     /**
      * Get the video source index.
      * @return video source index
@@ -535,18 +643,6 @@ public:
      */
     virtual void setMixCount(int count) = 0;
 
-    /**
-     * Get the playback count.
-     * @return The playback count.
-     */
-    virtual int getPlaybackCount() = 0;
-
-    /**
-     * Set the playback count.
-     * @param count The new playback count.
-     */
-    virtual void setPlaybackCount(int count) = 0;
-
     /**
      * Get the overlay intensity value.
      * @return The overlay intensity value.
