@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2017 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -22,9 +22,11 @@
 
 #include <QApplication>
 #include <QDebug>
+#include <QDesktopServices>
 #include <QFileDialog>
 #include <QMenuBar>
 #include <QStatusBar>
+#include <QUrl>
 #include <QWhatsThis>
 
 #include "mainwindowgui.h"
@@ -39,6 +41,7 @@
 #include "technical/util.h"
 #include "technical/videoencoder/ffmpegencoder.h"
 #include "technical/videoencoder/libavencoder.h"
+#include "technical/videoencoder/videoencoderfactory.h"
 
 using namespace Qt;
 
@@ -89,11 +92,13 @@ MainWindowGUI::MainWindowGUI(QApplication *stApp, Frontend *f)
     copyAct              = 0;
     pasteAct             = 0;
     preferencesAct       = 0;
-    whatsthisAct         = 0;
     undoViewAct          = 0;
     cameraControllerAct  = 0;
-    aboutAct             = 0;
+    whatsthisAct         = 0;
     helpAct              = 0;
+    onlineHelpAct        = 0;
+    aboutQtAct           = 0;
+    aboutAct             = 0;
 
     fileMenu             = 0;
     exportMenu           = 0;
@@ -135,11 +140,12 @@ MainWindowGUI::MainWindowGUI(QApplication *stApp, Frontend *f)
 
     grabber              = 0;
 
-    verticalGrid         = false;
-    verticalSpin         = 5;
-    horizontalGrid       = false;
-    horizontalSpin       = 5;
-    gridColor.setNamedColor("#000000");     // RGB Black
+    verticalGrid         = GeneralWidget::VERTICALGRIDDEFAULT;
+    verticalSpin         = GeneralWidget::VERTICALSPINDEFAULT;
+    horizontalGrid       = GeneralWidget::HORIZONTALGRIDDEFAULT;
+    horizontalSpin       = GeneralWidget::HORIZONTALSPINDEFAULT;
+    gridColor            = GeneralWidget::GRIDCOLORDEFAULT;
+    signal               = GeneralWidget::SIGNALDEFAULT;
 
     this->setObjectName("MainWindowGUI");
     stApp->installTranslator(&appTranslator);
@@ -202,6 +208,7 @@ void MainWindowGUI::retranslateStrings()
     undoViewAct->setText(tr("&Undo stack"));
     cameraControllerAct->setText(tr("&Camera Controller"));
     helpAct->setText(tr("&Help"));
+    onlineHelpAct->setText(tr("&Online Help"));
     aboutQtAct->setText(tr("About &Qt"));
     aboutAct->setText(tr("&About"));
 
@@ -490,14 +497,12 @@ void MainWindowGUI::initialize()
 {
     qDebug() << "MainWindowGUI::initialize --> Start";
 
-    int     value;
     QString gridColorName;
 
     lastVisitedDir.clear();
 
     this->initTranslations();
     PreferencesTool *pref = frontend->getPreferences();
-    QString activeLocale;
 
     pref->getStringPreference("preferences", "language", activeLocale);
     createTranslator(activeLocale);
@@ -565,27 +570,14 @@ void MainWindowGUI::initialize()
     connect(this, SIGNAL(startOpenProject()), this, SLOT(openProject()));
     connect(this, SIGNAL(startExit()),  this, SLOT(closeApplication()));
 
-    if (pref->getIntegerPreference("preferences", "verticalgrid", value) == false) {
-        value = false;
-    }
-    verticalGrid = value;
-
-    if (pref->getIntegerPreference("preferences", "verticalspin", verticalSpin) == false) {
-        verticalSpin = 5;
-    }
-
-    if (pref->getIntegerPreference("preferences", "horizontalgrid", value) == false) {
-        value = false;
-    }
-    horizontalGrid = value;
-
-    if (pref->getIntegerPreference("preferences", "horizontalspin", horizontalSpin) == false) {
-        horizontalSpin = 5;
-    }
-
+    pref->getBooleanPreference("preferences", "verticalgrid", verticalGrid);
+    pref->getIntegerPreference("preferences", "verticalspin", verticalSpin);
+    pref->getBooleanPreference("preferences", "horizontalgrid", horizontalGrid);
+    pref->getIntegerPreference("preferences", "horizontalspin", horizontalSpin);
     if (pref->getStringPreference("preferences", "gridcolor", gridColorName) == true) {
         gridColor.setNamedColor(gridColorName);
     }
+    pref->getBooleanPreference("preferences", "signal", signal);
 
     qDebug() << "MainWindowGUI::initialize --> End";
 }
@@ -644,21 +636,28 @@ void MainWindowGUI::keyPressEvent(QKeyEvent *k)
 }
 
 
+const QString MainWindowGUI::getActiveLocale()
+{
+    return activeLocale;
+}
+
+
 const QVector<QString> MainWindowGUI::getLanguages()
 {
-    return this->translationsLanguages;
+    return translationsLanguages;
 }
 
 
 const QVector<QString> MainWindowGUI::getLocales()
 {
-    return this->translationsLocales;
+    return translationsLocales;
 }
 
 
 void MainWindowGUI::changeLanguage(int newIndex)
 {
-    this->createTranslator(this->translationsLocales[newIndex]);
+    activeLocale = translationsLocales[newIndex];
+    createTranslator(activeLocale);
     retranslateStrings();
 }
 
@@ -729,6 +728,18 @@ void MainWindowGUI::setGridColorRGB(int r, int g, int b, int a)
 }
 
 
+bool MainWindowGUI::getSignal()
+{
+    return signal;
+}
+
+
+void MainWindowGUI::setSignal(bool newState)
+{
+    signal = newState;
+}
+
+
 void MainWindowGUI::showProgress(const QString &operation, unsigned int numOperations)
 {
     if (numOperations > 0) {
@@ -1007,6 +1018,54 @@ void MainWindowGUI::setRecordingMode(int mode)
 }
 
 
+int MainWindowGUI::getUnitMode()
+{
+    return recordingTab->getUnitMode();
+}
+
+
+void MainWindowGUI::setUnitMode(int mode)
+{
+    recordingTab->setUnitMode(mode);
+}
+
+
+int MainWindowGUI::getUnitCount()
+{
+    return recordingTab->getUnitCount();
+}
+
+
+void MainWindowGUI::setUnitCount(int count)
+{
+    recordingTab->setUnitCount(count);
+}
+
+
+bool MainWindowGUI::getBeepState()
+{
+    return recordingTab->getBeepState();
+}
+
+
+void MainWindowGUI::setBeepState(bool state)
+{
+    recordingTab->setBeepState(state);
+}
+
+
+int MainWindowGUI::getBeepCount()
+{
+    return recordingTab->getBeepCount();
+}
+
+
+void MainWindowGUI::setBeepCount(int count)
+{
+    recordingTab->setBeepCount(count);
+}
+
+
 int MainWindowGUI::getVideoSource()
 {
     return recordingTab->getVideoSource();
@@ -1126,18 +1185,6 @@ void MainWindowGUI::setMixCount(int count)
 }
 
 
-int MainWindowGUI::getPlaybackCount()
-{
-    return recordingTab->getPlaybackCount();
-}
-
-
-void MainWindowGUI::setPlaybackCount(int count)
-{
-    recordingTab->setPlaybackCount(count);
-}
-
-
 int MainWindowGUI::getOverlayIntensity()
 {
     return toolBar->getOverlayIntensity();
@@ -1189,11 +1236,27 @@ void MainWindowGUI::removeFileFromMonitoring(const QString &file)
     changeMonitor->removeFile(file);
 }
 
+
 void MainWindowGUI::removeAllFilesFromMonitoring()
 {
     changeMonitor->removeAllFiles();
 }
 
+
+void MainWindowGUI::openOnlineHelp(const QString &anchor)
+{
+    qDebug() << "MainWindowGUI::openOnlineHelp --> Start";
+
+    if ("de" == activeLocale) {
+        QDesktopServices::openUrl(QUrl("http://www.qstopmotion.org/manual/manual_de.html" + anchor));
+    }
+    else {
+        QDesktopServices::openUrl(QUrl("http://www.qstopmotion.org/manual/manual_en.html" + anchor));
+    }
+
+    qDebug() << "MainWindowGUI::openOnlineHelp --> End";
+}
+
 /**************************************************************************
  * Public slots
  **************************************************************************/
@@ -1412,14 +1475,14 @@ void MainWindowGUI::exportToVideo()
 {
     qDebug() << "MainWindowGUI::exportToVideo --> Start";
 
-    VideoEncoder    *enc = NULL;
+    VideoEncoder    *encoder = NULL;
     int              activeEncoderApplication;
     bool             useDefaultOutputFile;
 
     recordingTab->checkCameraOff();
 
     activeEncoderApplication = this->frontend->getProject()->getEncoderApplication();
-    if (activeEncoderApplication == VideoEncoder::noneApplication) {
+    if (activeEncoderApplication == DomainFacade::noneEncoderApplication) {
         frontend->showWarning(tr("Warning"),
                               tr("No encoder selected for the video export.\n"
                                  "This can be set in the properties dialog of the project.\n"
@@ -1430,12 +1493,12 @@ void MainWindowGUI::exportToVideo()
 
     switch (activeEncoderApplication)
     {
-    case VideoEncoder::ffmpegApplication:
-        enc = new FfmpegEncoder(this->frontend->getProject()->getAnimationProject());
+    case DomainFacade::ffmpegApplication:
+        encoder = new FfmpegEncoder(this->frontend->getProject()->getAnimationProject());
 
         break;
-    case VideoEncoder::libavApplication:
-        enc = new LibavEncoder(this->frontend->getProject()->getAnimationProject());
+    case DomainFacade::libavApplication:
+        encoder = new LibavEncoder(this->frontend->getProject()->getAnimationProject());
 
         break;
     default:
@@ -1447,19 +1510,19 @@ void MainWindowGUI::exportToVideo()
         QStringList  filters;
         QString      exportSuffix;
         QString      outputFile;
-        int          videoFormat = VideoEncoder::noneFormat;
+        int          videoFormat = DomainFacade::noneFormat;
 
         videoFormat = this->frontend->getProject()->getVideoFormat();
         switch(videoFormat) {
-        case VideoEncoder::aviFormat:
+        case DomainFacade::aviFormat:
             filters << tr("AVI Videos (*.avi)");
             exportSuffix.append("avi");
             break;
-        case VideoEncoder::mp4Format:
+        case DomainFacade::mp4Format:
             filters << tr("MP4 Videos (*.mp4)");
             exportSuffix.append("mp4");
             break;
-        case VideoEncoder::noneFormat:
+        case DomainFacade::noneFormat:
             frontend->showWarning(tr("Warning"),
                                   tr("No video format selected for the video export.\n"
                                      "This can be set in the properties dialog of the project.\n"
@@ -1478,19 +1541,19 @@ void MainWindowGUI::exportToVideo()
             outputFile.append(openFiles[0]);
         }
         if (outputFile.isEmpty()) {
-            delete enc;
-            enc = NULL;
+            delete encoder;
+            encoder = NULL;
             return;
         } else {
             if (!outputFile.endsWith(exportSuffix)) {
                 outputFile.append(".");
                 outputFile.append(exportSuffix);
             }
-            enc->setOutputFile(outputFile);
+            encoder->setOutputFile(outputFile);
         }
     } else {
         QString  outputFileName;
-        int      videoFormat = VideoEncoder::noneFormat;
+        int      videoFormat = DomainFacade::noneFormat;
 
         outputFileName = this->frontend->getProject()->getDefaultOutputFileName();
         if (outputFileName.isEmpty()) {
@@ -1502,39 +1565,46 @@ void MainWindowGUI::exportToVideo()
 
         videoFormat = this->frontend->getProject()->getVideoFormat();
         switch(videoFormat) {
-        case VideoEncoder::aviFormat:
+        case DomainFacade::aviFormat:
             if (outputFileName.indexOf(".avi") == -1) {
                 outputFileName.append(".avi");
             }
             break;
-        case VideoEncoder::mp4Format:
+        case DomainFacade::mp4Format:
             if (outputFileName.indexOf(".mp4") == -1 ) {
                 outputFileName.append(".mp4");
             }
             break;
         }
-        enc->setOutputFile(outputFileName);
+        encoder->setOutputFile(outputFileName);
     }
 
     // Remove an existing file
-    QFile::remove(enc->getOutputFile());
+    QFile::remove(encoder->getOutputFile());
 
-    if (!enc->isValid()) {
+    if (!encoder->isValid()) {
         frontend->showWarning(tr("Warning"),
                               tr("The selected encoder is not installed on your computer.\n"
                                  "Install the encoder or select another one!"));
-        delete enc;
-        enc = NULL;
+        delete encoder;
+        encoder = NULL;
         return;
     }
     checkSaved();
 
     frontend->showProgress(tr("Exporting ..."), frontend->getProject()->getTotalExposureSize());
-    frontend->getProject()->exportToVideo(enc);
+    // frontend->getProject()->exportToVideo(encoder);
+
+    VideoEncoderFactory factory(frontend);
+    if (factory.createVideoFile(encoder) != NULL) {
+        // Success
+        // return true;
+    }
+
     frontend->hideProgress();
 
-    delete enc;
-    enc = NULL;
+    delete encoder;
+    encoder = NULL;
 
     qDebug() << "MainWindowGUI::exportToVideo --> End";
 }
@@ -1559,7 +1629,7 @@ void MainWindowGUI::exportToCinelerra()
     }
 
     if (!outputFile.isNull()) {
-        frontend->getProject()->exportToCinelerra(outputFile);
+        // Not implemented jet
     }
 }
 
@@ -1743,9 +1813,10 @@ void MainWindowGUI::showCameraControllerDialog()
                                                             this);
         cameraControllerDialog->initialize();
         cameraControllerDialog->setGeometry(geometry().x() + fGeo.width(), geometry().y(),
-                                            200, height());
+                                            300, height());
     }
     cameraControllerDialog->show();
+    cameraControllerDialog->enableControls();
 
     if (frontend->isGrabberInited()) {
         cameraControllerDialog->setUp();
@@ -1770,6 +1841,12 @@ void MainWindowGUI::showHelpDialog()
 }
 
 
+void MainWindowGUI::showOnlineHelp()
+{
+    this->openOnlineHelp("#overview");
+}
+
+
 void MainWindowGUI::showAboutDialog()
 {
     AboutDialog *aboutDialog = new AboutDialog(frontend, this);
@@ -2285,6 +2362,15 @@ void MainWindowGUI::createActions()
     helpAct->setIconVisibleInMenu(true);
     connect(helpAct, SIGNAL(triggered()), this, SLOT(showHelpDialog()));
 
+    onlineHelpAct = new QAction(this);
+    iconFile.clear();
+    iconFile.append(frontend->getIconsDirName());
+    iconFile.append(QLatin1String("window.png"));
+    onlineHelpAct->setIcon(QIcon(iconFile));
+    onlineHelpAct->setShortcut(ControlModifier + Key_F1);
+    onlineHelpAct->setIconVisibleInMenu(true);
+    connect(onlineHelpAct, SIGNAL(triggered()), this, SLOT(showOnlineHelp()));
+
     aboutQtAct = new QAction(this);
     iconFile.clear();
     iconFile.append(frontend->getIconsDirName());
@@ -2363,6 +2449,7 @@ void MainWindowGUI::createMenus()
     helpMenu = new QMenu(this);
     helpMenu->addAction(whatsthisAct);
     helpMenu->addAction(helpAct);
+    helpMenu->addAction(onlineHelpAct);
     helpMenu->addSeparator();
     helpMenu->addAction(aboutQtAct);
     helpMenu->addAction(aboutAct);
@@ -2377,8 +2464,10 @@ void MainWindowGUI::makeToolsMenu(QHBoxLayout *layout)
     sideBar = new QTabWidget();
     sideBar->setObjectName("sideBar");
     sideBar->setTabPosition(QTabWidget::South);
-    sideBar->setMaximumWidth(250);
-    sideBar->setMinimumWidth(200);
+    // sideBar->setMaximumWidth(270);
+    // sideBar->setMinimumWidth(220);
+    // sideBar->setMinimumSize(170, 300);
+    sideBar->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
     layout->addWidget(sideBar);
 
     Q_ASSERT(frontend != 0);
@@ -2459,14 +2548,14 @@ void MainWindowGUI::makeViews(QHBoxLayout *layout)
     frameView = new FrameViewImage(frontend, this);
     // frameView = new FrameViewInterface(frontend, this);
 
-    frameView->setMinimumSize(400, 270);
+    // frameView->setMinimumSize(400, 270);
     frameView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     viewAreaLayout->addWidget(frameView);
 
     toolBar = new ToolBar(frontend, recordingTab);
     toolBar->setObjectName("ToolBar");
-    toolBar->setMinimumSize(400, 30);
+    // toolBar->setMinimumSize(400, 30);
     toolBar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     viewAreaLayout->addWidget(toolBar);
     // viewAreaLayout->addWidget(toolBar, 1, Qt::AlignJustify);
@@ -2574,6 +2663,13 @@ void MainWindowGUI::setMostRecentProject()
     Q_ASSERT(!newFirst.isEmpty());
 
     PreferencesTool *pref = frontend->getPreferences();
+
+    const QString oldFirst = pref->getProject(0);
+    if (oldFirst.compare(newFirst) == 0) {
+        // Old first is new first -> nothing to do
+        return;
+    }
+
     pref->removeProject(newFirst);
     pref->addProject(newFirst);
     pref->flushPreferences();
