@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2005-2016 by                                                *
+ *  Copyright (C) 2005-2017 by                                                *
  *    Bjoern Erik Nilsen (bjoern.nilsen@bjoernen.com),                        *
  *    Fredrik Berg Kjoelstad (fredrikbk@hotmail.com),                         *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
@@ -105,6 +105,12 @@ public:
      */
     void keyPressEvent(QKeyEvent *k);
 
+    /**
+     * Getting the active locale
+     * @return A string with the active locale
+     */
+    const QString getActiveLocale();
+
     /**
      * Getting all possible GUI languages
      * @return A vector with all languages
@@ -195,6 +201,18 @@ public:
      */
     void setGridColorRGB(int r, int g, int b, int a);
 
+    /**
+     * Get the status of the signal feature.
+     * @return The new state of the signal feature.
+     */
+    bool getSignal();
+
+    /**
+     * Set the status of the signal feature.
+     * @param newState The new state of the signal feature.
+     */
+    void setSignal(bool newState);
+
     /**
      * Function for displaying progress on timeconsuming operations.
      * @param infoText the text to display to the user
@@ -363,6 +381,56 @@ public:
      */
     void setRecordingMode(int mode);
 
+    /**
+     * Get the unit mode.
+     * @return The unit mode.
+     */
+    virtual int getUnitMode();
+
+    /**
+     * Set the unit mode.
+     * @param mode The new unit mode.
+     */
+    virtual void setUnitMode(int mode);
+
+    /**
+     * Get the unit count.
+     * @return The unit count.
+     */
+    virtual int getUnitCount();
+
+    /**
+     * Set the unit count.
+     * @param count The new unit count.
+     */
+    virtual void setUnitCount(int count);
+
+    /**
+     * Get the beep checkbox state.
+     * @brief getBeepState
+     * @return The actual beep checkbox state
+     */
+    virtual bool getBeepState();
+
+    /**
+     * Set the beep checkbox state.
+     * @brief setBeepState
+     * @param state The new beep checkbox state.
+     */
+    virtual void setBeepState(bool state);
+
+    /**
+     * Get the beep unit count.
+     * @return The beep unit count.
+     */
+    virtual int getBeepCount();
+
+    /**
+     * Set the beep unit count.
+     * @param count The new beep unit count.
+     */
+    virtual void setBeepCount(int count);
+
     /**
      * Get the video source index.
      * @return video source index
@@ -428,18 +496,6 @@ public:
      */
     void setMixCount(int count);
 
-    /**
-     * Get the playback count.
-     * @return The playback count.
-     */
-    int getPlaybackCount();
-
-    /**
-     * Set the playback count.
-     * @param count The new playback count.
-     */
-    void setPlaybackCount(int count);
-
     /**
      * Get the overlay intensity value.
      * @return The overlay intensity value.
@@ -492,6 +548,12 @@ public:
      */
     void removeAllFilesFromMonitoring();
 
+    /**
+     * Open the online help in the default internet browser
+     * @param anchor The anchor in the manual to go to after the manual is opend
+     */
+    void openOnlineHelp(const QString &anchor);
+
     /**************************************************************************
      * Public slots
      **************************************************************************/
@@ -591,7 +653,7 @@ private slots:
     void showCameraControllerDialog();
 
     /**
-     *
+     * Show the tool tip entries for user interface elements
      */
     void whatsThis();
 
@@ -600,6 +662,11 @@ private slots:
      */
     void showHelpDialog();
 
+    /**
+     * Brings up an help dialog with the qstopmotion user manua.
+     */
+    void showOnlineHelp();
+
     /**
      * Brings up an about dialog with information about the application.
      */
@@ -679,9 +746,10 @@ private:
     QAction *cameraControllerAct;
     // Help menu
     QAction *whatsthisAct;
+    QAction *helpAct;
+    QAction *onlineHelpAct;
     QAction *aboutQtAct;
     QAction *aboutAct;
-    QAction *helpAct;
 
     // Menues
     QMenu           *fileMenu;
@@ -727,6 +795,7 @@ private:
     ExternalChangeMonitor *changeMonitor;
 
     // Translation handling
+    QString                activeLocale;
     QTranslator            appTranslator;
     QTranslator            qtTranslator;
     QString                translationsPath;
@@ -741,6 +810,7 @@ private:
     bool                   horizontalGrid;
     int                    horizontalSpin;
     QColor                 gridColor;
+    bool                   signal;
 
     /**************************************************************************
      * Private functions
