@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2016 by                                                *
+ *  Copyright (C) 2010-2017 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -21,6 +21,7 @@
 #include "mfgrabber.h"
 #include "mfcontroller.h"
 #include "mfutil.h"
+#include "frontends/qtfrontend/preferences/grabberwidget.h"
 #include "technical/grabber/imageconverter.h"
 #include "technical/preferencestool.h"
 #include "technical/util.h"
@@ -98,7 +99,7 @@ bool MfGrabber::initialization(QVector<ImageGrabberDevice*> &devices)
     qDebug() << "MfGrabber::initialization --> Start";
 
     PreferencesTool *pref = frontend->getPreferences();
-    int              value;
+    bool             value;
 
     HRESULT             hr = S_OK;
     IMFAttributes*      pAttributes = NULL;
@@ -155,10 +156,10 @@ bool MfGrabber::initialization(QVector<ImageGrabberDevice*> &devices)
                 devices.append(device);
 
                 // Add the Controller to the new device
-                if (pref->getIntegerPreference("preferences", "mediafoundationcontroller", value) == false) {
-                    value = false;
+                if (pref->getBooleanPreference("preferences", "mediafoundationcontroller", value) == false) {
+                    value = Frontend::MEDIAFOUNDATIONCONTROLERDEFAULT;
                 }
-                if ((int)true == value) {
+                if (true == value) {
                     deviceController = new MfController(0);
                     device->setController(deviceController);
 
