@@ -1,5 +1,5 @@
 /******************************************************************************
- *  Copyright (C) 2010-2015 by                                                *
+ *  Copyright (C) 2010-2017 by                                                *
  *    Ralf Lange (ralf.lange@longsoft.de)                                     *
  *                                                                            *
  *  This program is free software; you can redistribute it and/or modify      *
@@ -32,6 +32,7 @@
 
 #include "v4l2controller.h"
 
+#include "frontends/qtfrontend/preferences/grabberwidget.h"
 #include "technical/util.h"
 #include "technical/grabber/imageconverter.h"
 
@@ -70,7 +71,7 @@ bool V4L2Grabber::initialization(QVector<ImageGrabberDevice*> &devices)
     qDebug() << "V4L2Grabber::initialization --> Start";
 
     PreferencesTool *pref = frontend->getPreferences();
-    int              value;
+    bool             value;
     int              deviceCount = 0;
 
     // Enumerate over all /dev/videoN (N = 0...x, x big enought)
@@ -98,10 +99,10 @@ bool V4L2Grabber::initialization(QVector<ImageGrabberDevice*> &devices)
             deviceCount++;
 
             // Add the Controller to the new device
-            if (pref->getIntegerPreference("preferences", "v4l2controller", value) == false) {
-                value = false;
+            if (pref->getBooleanPreference("preferences", "v4l2controller", value) == false) {
+                value = Frontend::V4L2CONTROLERDEFAULT;
             }
-            if ((int)true == value) {
+            if (true == value) {
                 deviceController = new V4L2Controller(0);
                 device->setController(deviceController);
 
@@ -591,8 +592,21 @@ bool V4L2Grabber::readDeviceInfo(int fd, ImageGrabberDevice *device)
     qDebug() << "V4L2Grabber::initialization --> Driver:" << (char*)(video_cap.driver);
     qDebug() << "V4L2Grabber::initialization --> Name:" << (char*)(video_cap.card);
 
-    device->setDeviceId(QLatin1String((const char*)video_cap.card));
-    device->setDeviceName(QLatin1String((const char*)video_cap.card) + " (V4L2)");
+    QString deviceCard = QLatin1String((const char*)video_cap.card);
+    QString deviceId = deviceCard;
+    QString deviceName = deviceCard;
+    int     separator = deviceCard.indexOf(':');
+    if (-1 != separator) {
+        // With separator
+        deviceId = deviceCard.left(separator);
+        deviceId = deviceId.trimmed();
+        deviceName = deviceCard.mid(separator + 1);
+        deviceName = deviceName.trimmed();
+
+    }
+
+    device->setDeviceId(deviceId);
+    device->setDeviceName(deviceName + " (V4L2)");
     device->setDeviceSource(ImageGrabberDevice::video4Linux2Source);
 
     enumerateCaptureFormats(fd, device);
