@@ -303,6 +303,93 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>Brightness:</source>
         <translation>Jas:</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished">Nápověda</translation>
+    </message>
+</context>
+<context>
+    <name>ControlerWidget</name>
+    <message>
+        <source>Below you can set which features of the camera should be used in the camera control dialog.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image quality controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Brightness control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Contrast control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saturation control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hue control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gamma control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sharpness control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Gain control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Camera controls</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exposure control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Focus control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pan control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tilt control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Iris control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Roll control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Backlight compensation control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>White balance control</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Color enable control</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DescriptionDialog</name>
@@ -354,6 +441,10 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>&amp;Scene Description:</source>
         <translation>Popis &amp;výjevu:</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished">Nápověda</translation>
+    </message>
 </context>
 <context>
     <name>DomainFacade</name>
@@ -538,6 +629,10 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>Input to program:</source>
         <translation>Vstup do programu:</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished">Nápověda</translation>
+    </message>
 </context>
 <context>
     <name>GeneralDialog</name>
@@ -581,6 +676,14 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>Grabber</source>
         <translation>Zachytávač obrazu</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished">Nápověda</translation>
+    </message>
+    <message>
+        <source>Camera Controler</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GeneralWidget</name>
@@ -624,6 +727,14 @@ rozhodnete pro přehrání, přehrána bez zvuku.</translation>
         <source>Insert new frame bevor selected frame</source>
         <translation>Vložení nového okénka před vybrané okénko (snímek filmu)</translation>
     </message>
+    <message>
+        <source>Signal Functionality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Take Picture Signal</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GrabberWidget</name>
@@ -746,11 +857,11 @@ zařízení pro práci s obrazem k počítači.</translation>
     <name>ImportWidget</name>
     <message>
         <source>0.1</source>
-        <translation>0,1</translation>
+        <translation type="vanished">0,1</translation>
     </message>
     <message>
         <source>5.0</source>
-        <translation>5,0</translation>
+        <translation type="vanished">5,0</translation>
     </message>
     <message>
         <source>BMP</source>
@@ -1280,6 +1391,10 @@ Install the encoder or select another one!</source>
         <translation>Vybraný kodér není nainstalován na vašem počítači.
 Kodér nainstalujte nebo vyberte jiný!</translation>
     </message>
+    <message>
+        <source>&amp;Online Help</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PreferencesTool</name>
@@ -1344,6 +1459,10 @@ Kodér nainstalujte nebo vyberte jiný!</translation>
         <source>Animation Project Properties</source>
         <translation>Vlastnosti projektu animace</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished">Nápověda</translation>
+    </message>
 </context>
 <context>
     <name>ProjectSerializer</name>
@@ -1537,7 +1656,7 @@ Kodér nainstalujte nebo vyberte jiný!</translation>
     </message>
     <message>
         <source>Playback</source>
-        <translation>Přehrávání</translation>
+        <translation type="vanished">Přehrávání</translation>
     </message>
     <message>
         <source>Video 4 Linux (USB WebCam)</source>
@@ -1581,12 +1700,68 @@ Kodér nainstalujte nebo vyberte jiný!</translation>
     </message>
     <message>
         <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
-        <translation>&lt;h4&gt;Počet obrázků&lt;/h4&gt; &lt;p&gt;Tímto posuvníkem (změnou hodnoty) můžete nastavit, kolik předcházejících obrázků v animaci se má zařadit v obrazu kamery. Nebo, pokud jste v režimu přehrávání: Kolik obrázků bude přehráno. &lt;/p&gt; &lt;p&gt;Tím (míšením předchozího obrázku(ů) do kamery) lépe uvidíte, jak je následující obrázek ve vztahu k předcházejícím obrázkům. To umožňuje stejnoměrný (hladší) průběh pohybu!&lt;/p&gt;</translation>
+        <translation type="vanished">&lt;h4&gt;Počet obrázků&lt;/h4&gt; &lt;p&gt;Tímto posuvníkem (změnou hodnoty) můžete nastavit, kolik předcházejících obrázků v animaci se má zařadit v obrazu kamery. Nebo, pokud jste v režimu přehrávání: Kolik obrázků bude přehráno. &lt;/p&gt; &lt;p&gt;Tím (míšením předchozího obrázku(ů) do kamery) lépe uvidíte, jak je následující obrázek ve vztahu k předcházejícím obrázkům. To umožňuje stejnoměrný (hladší) průběh pohybu!&lt;/p&gt;</translation>
     </message>
     <message>
         <source>Video 4 Linux 2 (USB WebCam)</source>
         <translation>Video 4 Linux (USB WebCam)</translation>
     </message>
+    <message>
+        <source>Time-lapse capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time-lapse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unit:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Beep</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>seconds before picture:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seconds between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Minutes between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera.&lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtFrontend</name>
@@ -1653,7 +1828,7 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     </message>
     <message>
         <source>Playback</source>
-        <translation>Přehrávání</translation>
+        <translation type="vanished">Přehrávání</translation>
     </message>
     <message>
         <source>No take selected. Please select a take on the project tab.</source>
@@ -1693,7 +1868,7 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     </message>
     <message>
         <source>Recording</source>
-        <translation>Nahrávání</translation>
+        <translation type="vanished">Nahrávání</translation>
     </message>
     <message>
         <source>No scene and no take selected. Please select a scene and a take on the project tab.</source>
@@ -1707,6 +1882,62 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
         <source>No active project. Please create a new project or open an existing project.</source>
         <translation>Žádný projekt není činný. Vytvořte, prosím, nový projekt nebo otevřete stávající projekt.</translation>
     </message>
+    <message>
+        <source>Recording mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time-lapse capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Time-lapse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unit:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Beep</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>seconds before picture:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seconds between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Minutes between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days between pictures</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Scene</name>
@@ -1757,6 +1988,10 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
         <source>Project path: </source>
         <translation>Cesta k projektu:</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation type="unfinished">Nápověda</translation>
+    </message>
 </context>
 <context>
     <name>TimeLine</name>
@@ -1800,11 +2035,11 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     <name>TransformWidget</name>
     <message>
         <source>0%</source>
-        <translation>0 %</translation>
+        <translation type="vanished">0 %</translation>
     </message>
     <message>
         <source>100%</source>
-        <translation>100 %</translation>
+        <translation type="vanished">100 %</translation>
     </message>
     <message>
         <source>Zoom the image</source>
@@ -1816,7 +2051,7 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
     </message>
     <message>
         <source>Zoom value:</source>
-        <translation>Hodnota zvětšení:</translation>
+        <translation type="vanished">Hodnota zvětšení:</translation>
     </message>
     <message>
         <source>Scale the whole image</source>
@@ -1838,6 +2073,18 @@ Potřebujete oprávnění ke čtení, zápisu a spouštění adresáře .qstopmo
         <source>Transformation settings</source>
         <translation>Nastavení proměny obrázku</translation>
     </message>
+    <message>
+        <source>Zoom value (%):</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Min</source>
+        <translation type="unfinished">Nejmenší</translation>
+    </message>
+    <message>
+        <source>Max</source>
+        <translation type="unfinished">Největší</translation>
+    </message>
 </context>
 <context>
     <name>UndoExposureAdd</name>
